Learn R Programming

RND (version 1.1)

oil.2012.10.01: West Texas Intermediate Crude Oil Options on 2013-10-01

Description

This dataset contains West Texas Intermediate (WTI) crude oil options with 43 days to expiration at the end of the business day October 1, 2012. On October 1, 2012, WTI closed at 92.44.

Usage

data(oil.2012.10.01)

Arguments

Format

A data frame with 332 observations on the following 7 variables.
type
a factor with levels C for call option P for put option
strike
option strike
settlement
option settlement price
openint
option open interest
volume
trading volume
delta
option delta
impliedvolatility
option implied volatility

CME posts sample data at: http://www.cmegroup.com/market-data/datamine-historical-data/endofday.html

Examples

Run this code
data(oil.2012.10.01)

Run the code above in your browser using DataLab